@@ -723,6 +723,23 @@ class TestResolver:
             resource=resource,
         )
 
+    def test_lookup_pointer_to_empty_string(self):
+        resolver = Registry().resolver_with_root(Resource.opaque({"": {}}))
+        assert resolver.lookup("#/").contents == {}
+
+    def test_lookup_non_existent_pointer_to_empty_string(self):
+        resource = Resource.opaque({"foo": {}})
+        resolver = Registry().resolver_with_root(resource)
+        with pytest.raises(
+            exceptions.Unresolvable,
+            match="^'/' does not exist within {'foo': {}}.*'#'",
+        ) as e:
+            resolver.lookup("#/")
+        assert e.value == exceptions.PointerToNowhere(
+            ref="/",
+            resource=resource,
+        )
+
     def test_lookup_non_existent_anchor(self):
         root = ID_AND_CHILDREN.create_resource({"anchors": {}})
         resolver = Registry().with_resource("urn:example", root).resolver()
@@ -738,6 +755,23 @@ class TestResolver:
             anchor="noSuchAnchor",
         )
 
+    def test_lookup_invalid_JSON_pointerish_anchor(self):
+        resolver = Registry().resolver_with_root(
+            ID_AND_CHILDREN.create_resource(
+                {
+                    "ID": "http://example.com/",
+                    "foo": {"bar": 12},
+                },
+            ),
+        )
+
+        valid = resolver.lookup("#/foo/bar")
+        assert valid.contents == 12
+
+        with pytest.raises(exceptions.InvalidAnchor) as e:
+            resolver.lookup("#foo/bar")
+        assert " '#/foo/bar'" in str(e.value)
+
     def test_lookup_retrieved_resource(self):
         resource = Resource.opaque(contents={"foo": "baz"})
         resolver = Registry(retrieve=lambda uri: resource).resolver()
